@@ -22,11 +22,18 @@ from publicstatic import source
 from publicstatic.cache import Cache
 
 
-def init(src_dir=None):
+def init(src_dir=None, force=False):
     """Create new website."""
-    conf.generate(src_dir)
+    conf.generate(src_dir, force)
     try:
-        helpers.copydir(conf.proto_dir(), conf.site_dir())
+        src = conf.proto_dir()
+        dest = conf.site_dir()
+        existing = helpers.copydir(src, dest, force=force)
+        if len(existing):
+            message = "some existing files were overwritten" if force else \
+                "some existing files were NOT overwritten (use --force " \
+                "to overwrite)"
+            logger.warn("%s\n- %s" % (message, '\n- '.join(existing)))
         logger.info('website created successfully, have fun!')
     except Exception as ex:
         logger.error('initialization failed: ' + str(ex))
@@ -39,6 +46,7 @@ def build(src_dir=None, def_tpl=False):
     if def_tpl:
         conf.set('default_templates', True)  # overriding parameter
     cache = Cache()
+    logger.info('build directory: ' + conf.get('build_path'))
     for builder in builders.order():
         builder(cache)
 
